@@ -10,7 +10,8 @@ from abc import ABC
 from dataclasses import dataclass, field
 from typing import Optional, Type
 import json
-from http_tools.http_server_connector import HttpServerConnector
+
+from http_tools import AbmServiceConnector
 from init_helpers.dict_to_dataclass import dict_to_dataclass
 from init_helpers.custom_json import custom_dumps
 from time_tools import Timerange
@@ -24,10 +25,10 @@ class DetectorSettings(ABC):
 
 class DetectorHttpConnector:
     @dataclass
-    class Context(HttpServerConnector.Context):
+    class Context(AbmServiceConnector.Context):
         project_name: str
 
-    Config = HttpServerConnector.Config
+    Config = AbmServiceConnector.Config
 
     def __init__(self,
                  config: Config,
@@ -35,7 +36,7 @@ class DetectorHttpConnector:
                  detector_settings_type: Type[DetectorSettings]) -> None:
         self.config = config
         self.context = context
-        self._connector = HttpServerConnector(config, context)
+        self._connector = AbmServiceConnector(config, context)
         self.detector_settings_type = detector_settings_type
 
     async def get_settings(self, rtsp_urls: list[str],
@@ -87,7 +88,4 @@ class DetectorHttpConnector:
             payload["token"] = token
         elif is_inner_request:
             headers["server_name"] = self.context.project_name
-        return await self._connector.post_json(url,
-                                               payload=payload,
-                                               headers=headers)
-
+        return await self._connector.post(url, payload=payload, headers=headers)
